<?php
$lang['invalidemail'] = 'Данный электронный адрес недействителен';
$lang['empty_query'] = 'Пустой запрос?? %s';
$lang['no_db_driver'] = 'Нет найдено ни одного драйвера базы данных';
$lang['test_check_output_buffering'] = 'Проверка output buffering';
$lang['test_check_output_buffering_failed'] = 'Output buffering выключен. Вероятно, вы не сможете использовать некоторые функции.';
$lang['phpinfo'] = 'Отображение информации PHP';
$lang['mod_security'] = 'Модуль Apache Mod Security';
$lang['test_check_tempnam'] = 'Проверка наличия функции tempnam';
$lang['test_check_db_drivers'] = 'Драйвера баз данных';
$lang['test_check_db_drivers_failed'] = 'Не найдены драйвера баз данных';
$lang['test_check_register_globals'] = 'Проверка PHP register globals';
$lang['test_check_register_globals_failed'] = 'PHP register globals включен. По соображениям безопасности, это должно быть отключено.';
$lang['test_check_disable_functions'] = 'Проверка отключенных PHP функций';
$lang['test_check_disable_functions_failed'] = 'Предупреждение: это список функций, которые отключены на вашем сервере.';
$lang['install_admin_db_port'] = 'Порт базы данных';
$lang['install_admin_db_port_info'] = 'Если неизвестно, то оставьте это поле пустым.';
$lang['install_admin_db_socket'] = 'Socket базы данных';
$lang['install_admin_db_socket_info'] = 'Не поддерживается.';
$lang['install_admin_frontendlang'] = 'Язык сайта по умолчанию. Это настраивает локаль, которая используется по для различных функций, напрмер, вывод дат и т.д.';
$lang['install_default_encoding'] = 'Почти во всех случаях, default_encoding должна быть UTF-8.';
$lang['installer_done'] = '[завершено]';
$lang['installer_failed'] = '[ошибка]';
$lang['create_permission'] = 'Создание прав ...';
$lang['add_column_sql'] = 'Добавление столбцов в таблицу %s ...';
$lang['update_table_sql'] = 'Обновление таблицы %s ...';
$lang['installing_module'] = 'Установка модуля %s ...';
$lang['updating_schema_version'] = 'Обновление схемы базы данных %s ...';
$lang['upgrade_config'] = 'Обновление config.php';
$lang['upgrade_config_info'] = 'конфигурация обновления';
$lang['upgrade_failed_again'] = 'Не удалось выполнить одно или несколько обновлений. Пожалуйста, исправьте проблему, и нажмите на кнопку ниже для новой проверки.';
$lang['upgrade_cache_dirs'] = 'Очистка кэша';
$lang['cannot_clean_cache_dirs'] = 'Невозможно очистить кэш!';
$lang['upgrade_schema'] = 'Обновление схемы';
$lang['need_upgrade_schema'] = 'CMS нуждается в обновлении.<br />В настоящее время вы работаете со схемой версии %s и вам нужно обновить её до версии %s';
$lang['schema_ok'] = 'База данных не требует обновления.  Используется схема версии %s';
$lang['noneed_upgrade_schema'] = 'База данных не требует обновления.  Используется схема версии %s';
$lang['upgrade_modules'] = 'Обновление модулей';
$lang['noneed_upgrade_modules'] = 'Стандартные модули не требуют обновления';
$lang['upgrade_sql_module_from_to'] = 'Обновление SQL для модуля "%s" с %s по %s ...';
$lang['upgrade_event_module_from_to'] = 'Обновление события для модуля "%s" с %s по %s ...';
$lang['sitedown_not_removed'] = 'Не удалось удалить файл tmp/cache/SITEDOWN. Удалите его вручную, чтобы удалить сообщение "Сайт закрыт на техническое обслуживание" на вашем сайте';
$lang['upgrade_ok'] = 'Пожалуйста, проверьте config.php, измените настройки по мере необходимости, и после изменения удалите доступ на запись к файлу. Кроме того, Вы должны убедиться в том, что все ваши модули актуальны, перейдите к Расширения -> Модули и проверьте список на наличие модулей нуждающихся в обновлении';
$lang['upgrade_complete'] = 'Обновление завершено';
$lang['upgrade_end'] = 'CMS не требует обновления. Нажмите на %s чтобы перейти на сайт или на %s.';
$lang['here'] = 'здесь';
$lang['go_to_admin'] = 'Перейти в административный интерфейс';
$lang['errorfilenot'] = 'Файл не найден!';
$lang['errorfilenotwritable'] = 'Файл не доступен для записи!';
$lang['nofiles'] = 'Данный ресурс не существует!';
$lang['is_directory'] = 'Данный ресурс представляет собой каталог!';
$lang['is_readable_false'] = 'Данный ресурс невозможно открыть для чтения!';
$lang['checksum_match'] = 'Контрольная сумма совпадает!';
$lang['checksum_not_match'] = 'Контрольная сумма не совпадает!';
$lang['not_checksum'] = 'Не удалось получить контрольную сумму!';
$lang['format_datetime'] = '%c ';
$lang['upload_err_ini_size'] = 'Размер загружаемого файла превышает значение upload_max_filesize в php.ini!';
$lang['upload_err_form_size'] = 'Размер загружаемого файла превышает значение MAX_FILE_SIZE, указанное в HTML форме.';
$lang['upload_err_partial'] = 'Файл был загружен лишь частично.';
$lang['upload_err_no_file'] = 'Файл не был загружен.';
$lang['upload_err_no_tmp_dir'] = 'Отсутствует временная папка.';
$lang['upload_err_cant_write'] = 'Не удалось записать файл на диск.';
$lang['upload_err_extension'] = 'Загрузка файла остановлена.';
$lang['upload_err_empty'] = 'Файл имеет размер 0.';
$lang['upload_err_unknown'] = 'Неизвестная ошибка во время загрузки файла.';
$lang['function_file_uploads_off'] = 'file_uploads отключен в вашей конфигурации PHP!';
$lang['upload_file_no_readable'] = 'Загруженный файл не читаем!';
$lang['upload_file_multiple'] = 'Параллельная загрузка нескольких файлов не допускается!';
$lang['test_check_magic_quotes_gpc'] = 'Magic quotes для операций Get/Post/Cookie';
$lang['test_check_magic_quotes_gpc_failed'] = 'При включении magic_quotes все одинарные и двойные кавычки, а также слеш будут маскироваться автоматически. Это может привести к серьезным проблемам.';
$lang['test_check_magic_quotes_runtime'] = 'Magic quotes в выполнении';
$lang['test_check_magic_quotes_runtime_failed'] = 'При включении magic_quotes большинство функций, возвращающих данные из какого-либо внешнего источника, включая базы данных и текстовые файлы, будут иметь маскировку кавычек. Это может привести к серьезным проблемам.';
$lang['install_admin_checksum'] = 'Проверить закачанные файлы';
$lang['upgrade_admin_checksum'] = 'Проверьте вашу систему на обновления';
$lang['checksum'] = 'Проверка контрольной суммы';
$lang['checksum_file'] = 'Файл с контрольной суммой';
$lang['install_test_checksum'] = 'Вы можете проверить целостность файлов вашей системы путем сравнения с первоначальной контрольной суммой. Она может помочь в поиске проблем с закачкой на сервер.';
$lang['checksum_passed'] = 'Все контрольные суммы совпадают!';
$lang['checksum_failed'] = 'Контрольные суммы указывают на ошибки. Обратитесь в помощь за дополнительной информацией';
$lang['test_check_open_basedir'] = 'Опция open_basedir';
$lang['test_check_open_basedir_failed'] = 'Опция open_basedir включена в конфигурационном файле httpd.conf. У Вас могут возникнуть трудности с некоторыми функциями.';
$lang['unlimited'] = 'Неограничено';
$lang['test_open_basedir_session_save_path'] = 'Опция open_basedir включена в конфигурационном файле httpd.conf. Если у вас возникают проблемы с сессиями и при этом есть возможность использования функции ini_set, то Вы можете попытаться решить проблему при помощи cookie: ini_set(\'session.use_only_cookies\', 1); (добавить в начало файла include.php)';
$lang['install_warn_db_createtables'] = 'Как правило, это поле должно быть выбрано. Будьте осторожны при отключении этой функции.';
$lang['install_admin_tablesnotcreated'] = 'Процесс завершен. Установка завершена, по Вашему желанию таблицы в базе данных не были созданы. Вместе с тем, настройки конфигурационного файла были сброшены и все установочные тесты прошли испытания. Спасибо, а вот ваше';
$lang['info_create_dir_and_file'] = 'Процесс HTTP не может создать файл внутри каталога, которым он владеет. Это может означать, что на сервере активирован безопасный режим (safe mode). Многие функции внутри CMS Made Simple будут работать неправильно в этом режиме. Продолжение не возможно.';
$lang['test_create_dir_and_file'] = 'Проверка, может ли httpd процесс создать файл внутри созданного каталога.';
$lang['cms_site'] = 'CMS сайт';
$lang['or_greater'] = 'Или выше';
$lang['sitename'] = 'Название сайта';
$lang['warning_safe_mode'] = '<strong><em>ВНИМАНИЕ:</ em></strong>В php включен безопасный режим. Это вызовет трудности при загрузке файлов через интерфейс обозревателя, включая изображения, шаблоны и XML пакеты модулей. Вам рекомендуется обратиться к администратору сайта по поводу отключения безопасного режима в php.';
$lang['test'] = 'Тест';
$lang['results'] = 'Результат';
$lang['untested'] = 'Не протестирован';
$lang['owner'] = 'Владелец';
$lang['permissions'] = 'Права';
$lang['off'] = 'Отключен';
$lang['on'] = 'Включен';
$lang['permission_information'] = 'Информация о правах';
$lang['server_os'] = 'Операционная система';
$lang['server_api'] = 'Программный интерфейс';
$lang['server_software'] = 'Программа';
$lang['server_information'] = 'Информация';
$lang['session_save_path'] = 'Переменная session.save_path';
$lang['max_execution_time'] = 'Переменная max_execution_time';
$lang['gd_version'] = 'Версия библиотеки GD';
$lang['upload_max_filesize'] = 'Максимальный размер загружаемого файла';
$lang['post_max_size'] = 'Максимальный размер запроса через POST';
$lang['memory_limit'] = 'Переменная memory_limit';
$lang['server_db_type'] = 'СУБД';
$lang['server_db_version'] = 'Версия СУБД';
$lang['phpversion'] = 'Версия PHP';
$lang['safe_mode'] = 'Безопасный режим';
$lang['php_information'] = 'Информация о PHP';
$lang['cms_install_information'] = 'Установочная информация';
$lang['cms_version'] = 'Версия CMS';
$lang['systeminfo_copy_paste'] = 'Скопируйте и вставьте выделенный текст в вашe сообщение в форуме.';
$lang['help_systeminformation'] = 'Информация отображаемая ниже собрана из конфигурационных данных Вашего сервера и представлена здесь в сжатом виде, для того, чтобы вы сразу могли увидеть все настройки при попытке диагностировать проблему или обращении за помощью с вашей установкой.';
$lang['systeminfo'] = 'Информация о системе';
$lang['systeminfodescription'] = 'Показ различной информации о Вашей системе, которая может быть полезна при диагностике проблемы.';
$lang['error'] = 'Ошибка';
$lang['new_version_available'] = '<em>Примечание:</em> Вышла новая версия CMS Made Simple. Просьба сообщить об этом администратору.';
$lang['info_urlcheckversion'] = 'Если эта ссылка является словом "none", то проверка выполняться не будет.<br/>Пустой результат приведет к использованию ссылки, установленной по умолчанию.';
$lang['urlcheckversion'] = 'Проверять наличие новой версии CMS, используя эту ссылку';
$lang['read'] = 'Чтение (read)';
$lang['write'] = 'Запись (write)';
$lang['execute'] = 'Выполнение (execute)';
$lang['group'] = 'Группа (group)';
$lang['other'] = 'Другие (other)';
$lang['global_umask'] = 'Права доступа по умолчанию (umask)';
$lang['errorcantcreatefile'] = 'Невозможно создать файл (проблемы с доступом?)';
$lang['add'] = 'Добавить';
$lang['about'] = 'Инфо';
$lang['action'] = 'Действие';
$lang['actionstatus'] = 'Действие/Статус';
$lang['active'] = 'Активен';
$lang['cantremove'] = 'Невозможно удалить';
$lang['changepermissions'] = 'Изменить права';
$lang['changepermissionsconfirm'] = 'БУДЬТЕ ОСТОРОЖНЫ\\n\\nЭтой командой всем файлам модуля будет дано право на запись сервером.\\nВы действительно хотите продолжить?';
$lang['success'] = 'Удачное завершение';
$lang['advanced'] = 'Расширенный';
$lang['back'] = 'Вернуться к меню';
$lang['cancel'] = 'Отменить';
$lang['cantchmodfiles'] = 'Невозможно изменить права доступа к некоторым файлам';
$lang['cantremovefiles'] = 'Проблема при удалении файлов (права доступа?)';
$lang['create'] = 'Создать';
$lang['database'] = 'База данных';
$lang['databaseprefix'] = 'Префикс к базе данных';
$lang['databasetype'] = 'Тип базы данных';
$lang['date'] = 'Дата';
$lang['default'] = 'По умолчанию';
$lang['delete'] = 'Удалить';
$lang['deleteconfirm'] = 'Вы уверены, что хотите удалить - %s - ?';
$lang['description'] = 'Описание';
$lang['directoryexists'] = 'Такой каталог уже существует';
$lang['down'] = 'Вниз';
$lang['edit'] = 'Редактировать';
$lang['email'] = 'Адрес электронной почты';
$lang['errordeletingfile'] = 'Невозможно удалить файл. Проблемы с правами доступа?';
$lang['errordirectorynotwritable'] = 'Нет разрешения на запись в каталоге. Это может зависеть от прав на доступ к файлу и его владельца. Безопасный режим также может привести к этой ошибке.';
$lang['cachenotwritable'] = 'Нет разрешения на запись в каталоге cache. Очистка кэша не будет работать. Пожалуйста, назначьте для каталога tmp/cache права доступа "чтение/запись/выполнение" (777). Возможно Вам также понадобится отключить безопасный режим.';
$lang['modulesnotwritable'] = 'Нет разрешения на запись в каталоге modules. Если вы хотите устанавливать модули при помощи загрузки файлами XML, то для каталога modules должны быть назначены права доступа "чтение/запись/выполнение" (777). Возможно Вам также понадобится отключить безопасный режим.';
$lang['false'] = 'False ';
$lang['settrue'] = 'Установить True';
$lang['filename'] = 'Название файла';
$lang['filesize'] = 'Размер файла';
$lang['help'] = 'Помощь';
$lang['language'] = 'Язык';
$lang['lastname'] = 'Фамилия';
$lang['name'] = 'Имя';
$lang['password'] = 'Пароль';
$lang['passwordagain'] = 'Пароль (повтор)';
$lang['remove'] = 'Удалить';
$lang['saveconfig'] = 'Сохранить конфигурацию';
$lang['true'] = 'True ';
$lang['setfalse'] = 'Установить False';
$lang['type'] = 'Тип';
$lang['typenotvalid'] = 'Тип не действителен';
$lang['unknown'] = 'Неизвестно';
$lang['user'] = 'Пользователь';
$lang['userdefinedtags'] = 'Пользовательские теги';
$lang['usermanagement'] = 'Управление пользователями';
$lang['username'] = 'Логин';
$lang['usernameincorrect'] = 'Логин или пароль неверен';
$lang['version'] = 'Версия';
$lang['install_title'] = 'Установка CMS Made Simple (шаг %s)';
$lang['install_system'] = 'Установка системы';
$lang['install_thanks'] = 'Благодарим за установку CMS Made Simple';
$lang['upgrade_title'] = 'Обновление CMS Made Simple (step %s)';
$lang['upgrade_system'] = 'Обновление системы';
$lang['upgrade_thanks'] = 'Спасибо за обновление CMS Made Simple до версии ';
$lang['install_please_read'] = 'Пожалуйста, прочитайте главу <a href="http://wiki.cmsmadesimple.org/index.php/User_Handbook/Installation/Troubleshooting/ru">Решение проблем</a> в документации CMS Made Simple Wiki.';
$lang['install_checking'] = 'Проверка прав и настроек PHP';
$lang['install_test'] = 'Тест';
$lang['install_result'] = 'Результат';
$lang['install_required_settings'] = 'Требуемая конфигурация';
$lang['install_recommended_settings'] = 'Рекомендуемая конфигурация';
$lang['install_you_have'] = 'У Вас';
$lang['install_legend'] = 'Наименования';
$lang['install_symbol'] = 'Символ';
$lang['install_definition'] = 'Определение';
$lang['install_value_passed'] = 'Тест успешно пройден';
$lang['install_value_failed'] = 'Тест не пройден';
$lang['install_error_fragment'] = 'Помощь по решению проблем';
$lang['install_value_required'] = 'Значение ниже требуемого минимального значения';
$lang['install_value_recommended'] = 'Значение выше требуемого минимального значения, но ниже рекомендуемого значения<br /> или ... <em>Возможны</em> сбои в выполнении некоторых функций.';
$lang['install_value_exceed'] = 'Значение соответствует или превышает рекомендуемое значение, но ниже рекомендуемого значения';
$lang['install_test_failed'] = 'Один или несколько тестов не пройдены. Вы все же можете установить систему, но некоторые функции могут работать неправильно.<br />Попробуйте исправить проблему и нажмите кнопку "Повторить", или нажмите кнопку "Продолжить".';
$lang['install_test_passed'] = 'Все тесты успешно пройдены (по крайней мере на минимальном уровне). Пожалуйста, нажмите кнопку "Далее".';
$lang['install_failed_again'] = 'Один или несколько тестов не были пройдены. Пожалуйста, исправьте проблему и нажмите на кнопку ниже для перепроверки.';
$lang['install_try_again'] = 'Повторить';
$lang['install_continue'] = 'Продолжить';
$lang['failure'] = 'Сбой';
$lang['caution'] = 'Осторожно';
$lang['install_admin_umask'] = 'Проверить права доступа по умолчанию';
$lang['install_test_umask'] = 'Пожалуйста, нажмите кнопку "Тест" для проверки ..............................';
$lang['test_umask_text'] = 'Umask (user file-creation mode mask) – это встроенная в оболочку команда, определяющая права доступа, по умолчанию назначаемые всем новым файлам при их создании. Это значение может быть перезаписано системными вызовами многих программ и утилит, использующих umask.';
$lang['test_check_umask'] = 'Результат тестирования на файле созданном в';
$lang['test_umask_not_given'] = 'Не задан umask';
$lang['test_check_umask_failed'] = 'Тестирование umask не пройдено';
$lang['test_username_not_given'] = 'Не задан логин!';
$lang['test_username_illegal'] = 'Логин содержит недопустимые символы!';
$lang['test_not_both_passwd'] = 'Одно из полей для пароля не заполнено!';
$lang['test_passwd_not_match'] = 'Пароль и повтор не совпадают!';
$lang['test_email_accountinfo'] = 'Отправка сообщения по электронной почте активирована, но не задан адрес!';
$lang['test_database_prefix'] = 'Префикс к базе данных содержит недопустимые символы!';
$lang['test_no_dbms'] = 'Не выбрана СУБД!';
$lang['test_could_not_connect_db'] = 'Не удалось установить соединение к базе данных. Убедитесь, что правильно заданы имя пользователя и пароль, и этот пользователь имеет доступ к данной базе данных.';
$lang['test_could_not_drop_table'] = 'Невозможно удалить таблицу. Убедитесь, что у пользователя есть права на удаление таблиц в данной базе данных.';
$lang['test_could_not_create_table'] = 'Невозможно создать таблицу.Убедитесь, что у пользователя есть права на создание таблиц в данной базе данных.';
$lang['test_check_php'] = 'Проверка версии PHP %s+';
$lang['test_min_recommend'] = '(минимально %s, рекомендуемо %s или выше)';
$lang['test_min_recommend_plus'] = '(минимально %s, рекомендуемо %s+)';
$lang['test_requires_php_version'] = 'CMS Made Simple требует версии PHP 4.3 или выше (у вас %s), при этом PHP  %s или выше рекомендовано, чтобы обеспечить максимальную совместимость с дополнительными модулями';
$lang['test_check_md5_func'] = 'Проверка наличия функции md5';
$lang['test_check_safe_mode'] = 'Проверка безопасного режима';
$lang['test_check_safe_mode_failed'] = 'Включение безопасного режима PHP может привести к проблема с загрузкой файлов и другим сбоям в работе. Это зависит от строгости настройки безопасного режима.';
$lang['test_check_tokenizer'] = 'Проверка наличия функций tokenizer';
$lang['test_check_tokenizer_failed'] = 'Отсутствие функций tokenizer может привести к показу пустых страниц. Эти функции требуются для успешной установки.';
$lang['test_check_gd'] = 'Проверка наличия библиотеки GD';
$lang['test_check_gd_failed'] = 'Наличие библиотеки GD является обязательным для некоторых модулей и функциональности.';
$lang['test_check_write'] = 'Проверка прав на запись';
$lang['test_may_not_exist'] = 'Возможно, что этот файл еще не создан. Если это так, то вы должны создать пустой файл с таким именем. Следует также убедиться, что данный файл имеет доступ для записи сервером.';
$lang['could_not_retrieve_a_value'] = 'Не удалось получить значение .... не критично.';
$lang['displaying_the_value_originally'] = '<br />Показ значения первоначально установленного в конфигурационный файл (может быть не точным).';
$lang['test_check_xml_func'] = 'Проверка на базовую поддержку XML (expat)';
$lang['test_check_xml_failed'] = 'Поддержка XML отсутствует в сборке PHP. Несмотря на это Вы можете использовать систему, но возможно не сможете воспользоваться тем или иным дополнительным модулем или функцией.';
$lang['test_allow_url_fopen_failed'] = 'При отключенной переменной allow_url_fopen Вы не будете иметь доступа к URL файла, используя ftp или http протокол.';
$lang['test_remote_url'] = 'Проверка удаленной ссылки';
$lang['test_remote_url_failed'] = 'Вы, вероятно, не сможете открыть файл на удаленном веб-сервере.';
$lang['connection_error'] = 'Невозможны исходящие HTTP-соединения! Возможно идет блокировка внешних подключений в firewall или ACL. Это нарушит работу менеджера модулей, и, возможно, других функций.';
$lang['remote_connection_timeout'] = 'Тайм-аут подключения!';
$lang['search_string_find'] = 'Подключение OK!';
$lang['connection_failed'] = 'Ошибка соединения!';
$lang['remote_response_ok'] = 'Удаленный ответ: ОК!';
$lang['remote_response_404'] = 'Удаленный ответ: не найдено!';
$lang['remote_response_error'] = 'Удаленный ответ: ошибка!';
$lang['test_check_file_upload'] = 'Проверка загрузки файлов';
$lang['test_check_file_failed'] = 'Если отключена переменная file_uploads, то Вы не сможете воспользоваться функциями загрузки файлов в CMS Made Simple. По возможности это ограничение должно быть снято администратором сервера для правильного использования всех функции управления файлами в системе. Будьте осторожны.';
$lang['test_check_memory'] = 'Проверка переменной memory_limit';
$lang['test_check_memory_failed'] = 'Возможно, Ваш сервер не имеет достаточно памяти для запуска CMSMS со всеми нужными модулями. Если возможно, Вам следует попросить администратора сервера поднять это значение. Будьте осторожны.';
$lang['test_check_time_limit'] = 'Проверка переменной time_limit';
$lang['test_check_time_limit_failed'] = 'Количество секунд, для запуска скриптов. Если это время будет превышено, то скрипт возвратит фатальную ошибку.';
$lang['test_check_post_max'] = 'Проверка переменной post_max_size';
$lang['test_check_post_max_failed'] = 'Вероятно Вы не сможете передавать большее количество данных через формы. Учитывайте это ограничение в работе.';
$lang['test_check_upload_max'] = 'Проверка переменной upload_max_filesize';
$lang['test_check_upload_max_failed'] = 'Вероятно Вы не сможет загружать (крупные) файлы при использовании функций управления файлами. Учитывайте это ограничение в работе.';
$lang['test_check_writable'] = 'Проверка %s на доступ для записи';
$lang['test_check_upload_failed'] = 'Каталог uploads не имеет прав на запись. Несмотря на это Вы можете установить систему, но вы не сможете загружать файлы из административного интерфейса.';
$lang['test_check_images_failed'] = 'Каталог images не имеет прав на запись. Несмотря на это Вы можете установить систему, но вы не сможете загружать файлы из административного интерфейса.';
$lang['test_check_modules_failed'] = 'Каталог modules не имеет прав на запись. Несмотря на это Вы можете установить систему, но вы не сможете загружать модули из административного интерфейса.';
$lang['test_check_file_get_contents'] = 'Проверка наличия file_get_contents';
$lang['test_check_file_get_contents_failed'] = 'Вероятно Вы не сможете воспользоваться какой-либо функциональностью, требующую наличия этой функции.';
$lang['test_check_session_save_path'] = 'Проверка пути session.save_path на запись';
$lang['test_empty_session_save_path'] = 'Путь session.save_path пуст. PHP будет использовать временный каталог вашей операционной системы. Если у вас есть проблемы с использованием сессий и возможность использования ini_set, то Вы можете добавить использование cookies:  ini_set( \'session.use_only_cookies\', 1); в самом начале файла include.php';
$lang['test_check_session_save_path_failed'] = 'Путь session.save_path = "%s". Если этот путь не имеет прав на запись, то возможно у Вас возникнут проблемы при входе в административный интерфейс. Вы должны обеспечить права на запись, если у Вас возникают проблемы при входе в административный интерфейс. Данная проверка может завершиться неудачно при включенном безопасном режиме (см. ниже).';
$lang['test_check_ini_set'] = 'Проверка на использование ini_set';
$lang['test_check_ini_set_failed'] = 'Хотя использование этой функции php не является обязательным, некоторые модули используют ее (опционально) для увеличения тайм-аута  и разрешения для загрузки больших файлов и т.д. У Вас могут возникнуть трудности с использованием некоторых модулей без этой возможности. Данная проверка может завершиться неудачно при включенном безопасном режиме (см. ниже).';
$lang['install_admin_header'] = 'Информация об учетной записи администратора';
$lang['install_admin_info'] = 'Выберите логин, пароль и адрес электронной почты для вашей учетной записи администратора. Убедитесь, что вы запомнили этот пароль.';
$lang['install_admin_email'] = 'Адрес электронной почты';
$lang['install_admin_email_info'] = 'Учетная информация адреса электронной почты';
$lang['install_admin_email_note'] = '<strong>Примечание:</strong>Эта функция использует php функцию mail. Если Вы не получите это письмо, это может быть свидетельством того, что ваш сервер не правильно настроен, и что вам необходимо связаться с администратором Вашего сервера.';
$lang['install_admin_sitename'] = 'Это название Вашего сайта. Оно будет использоваться в шаблонах и может быть использована в любом другом месте при вставке тега {sitename}.';
$lang['install_admin_db'] = 'Информация о базе данных';
$lang['install_admin_db_info'] = '<p>Убедитесь, что вы создали базу данных и заданный пользователь достаточно прав для использования этой базы.</p>
<p>Для MySQL:</p>
<p>Войдите в mysql из консоли и выполните следующие команды:</p>
<ol>
<li>create database cms; (используйте любое имя, но обязательно запомните его, так как его нужно ввести на этой странице)</li>
<li>grant all privileges on cms.* to cms_user@localhost identified by \'cms_pass\';</li>
</ol>';
$lang['install_admin_follow'] = 'Пожалуйста, заполните следующие поля';
$lang['install_admin_db_type'] = 'Тип базы данных';
$lang['install_admin_no_db'] = 'Не найден драйвер для базы данных в Вашей сборке PHP. Пожалуйста, убедитесь, что у Вас установлена поддержка для mysql, mysli или postgre7 и повторите установку.';
$lang['install_admin_db_host'] = 'Имя сервера СУБД';
$lang['install_admin_db_name'] = 'Имя базы данных';
$lang['install_admin_db_create'] = 'Создать таблицы (Осторожно: уже созданные таблицы будут удалены)';
$lang['install_admin_db_prefix'] = 'Префикс к таблицам';
$lang['install_admin_db_sample'] = 'Установить примеры контента и шаблоны';
$lang['retry'] = 'Повторить';
$lang['install_admin_db_create_seq'] = 'Создание счетчика на таблицу %s ...';
$lang['install_admin_importing'] = 'Импорт примеров...';
$lang['invalid_query'] = 'Неверный запрос: %s';
$lang['install_creating_table'] = '<p>Создание %s таблицы... [%s]</p>';
$lang['install_creating_index'] = '<p>Созднание индекса для %s таблицы... [%s]</p>';
$lang['done'] = 'готово';
$lang['failed'] = 'ошибка';
$lang['install_admin_error_schema'] = 'Ошибка при чтении SQL схемы';
$lang['install_admin_set_account'] = 'Настройка учетной записи администратора ...';
$lang['install_admin_set_sitename'] = 'Настройка названия сайта ...';
$lang['install_admin_setup'] = 'Продолжение настройки Вашего конфигурационного файла, мы уже имеем большинство нужной нам информации. Скорее всего вы можете оставить все эти значения без изменений. Когда вы будете готовы, нажмите на кнопку "Далее".';
$lang['install_admin_docroot'] = 'Путь к корневому каталогу CMS (исходя из веб-сервера)';
$lang['install_admin_docroot_path'] = 'Путь к корневому каталогу веб-сервера';
$lang['install_admin_querystring'] = 'Строка запроса (оставьте без изменений, если у Вас не возникнут проблемы, затем отредактируйте config.php вручную)';
$lang['invalid_querys'] = '<b>ВНИМАНИЕ<b/>: Ошибки в запросах к базе данных!';
$lang['install_admin_sitedown'] = 'Ошибка: Невозможно удалить файл tmp/cache/SITEDOWN. Удалите вручную.';
$lang['install_admin_update_hierarchy'] = 'Обновление иерархии позиций ...';
$lang['install_admin_set_core_event'] = 'Настройка основных событий ...';
$lang['install_admin_install_modules'] = 'Установка модулей ...';
$lang['install_admin_index_search'] = 'Индексирование поиска ...';
$lang['install_admin_clear_cache'] = 'Очистка кэша сайта (если необходимо)...';
$lang['install_admin_emailing'] = 'Отправка информации об учетной записи администратора по электронному адресу ...';
$lang['install_admin_congratulations'] = 'Поздравляем, все настроено - здесь ';
$lang['could_not_connect_db'] = 'Не удалось установить соединение к базе данных. Убедитесь, что правильно заданы имя пользователя и пароль, и этот пользователь имеет доступ к данной базе данных.';
$lang['cannot_write_config'] = 'Ошибка: Невозможна запись в %s.';
$lang['email_accountinfo_subject'] = 'Учетная запись администратора CMS Made Simple ';
$lang['email_accountinfo_message'] = 'Спасибо за установку  CMS Made Simple.

Информация о Вашей учетной записи:
Логин: %s
Пароль: %s

Вход в административный интерфейс сайта: %s';
$lang['utmz'] = '156861353.1249691644.74.46.utmccn=(referral)|utmcsr=localhost|utmcct=/msnew/install/index.php|utmcmd=referral';
$lang['utma'] = '156861353.1512485689.1236874721.1249691644.1250401334.75';
$lang['utmc'] = '156861353';
$lang['qca'] = 'P0-738804097-1250401341499';
$lang['utmb'] = '156861353.1.10.1250401334';
?>